@@ -142,7 +142,10 @@ items = project.repository_tree(path='docs', ref='branch1')
 # end repository tree
 
 # repository blob
-file_content = p.repository_blob('master', 'README.rst')
+items = project.repository_tree(path='docs', ref='branch1')
+file_info = p.repository_blob(items[0]['id'])
+content = base64.b64decode(file_info['content'])
+size = file_info['size']
 # end repository blob
 
 # repository raw_blob
@@ -379,17 +382,24 @@ project.upload("filename.txt", filedata="Raw data")
 # end project file upload with data
 
 # project file upload markdown
-uploaded_file = project.upload_file("filename.txt", filedata="data")
+uploaded_file = project.upload("filename.txt", filedata="data")
 issue = project.issues.get(issue_id)
 issue.notes.create({
     "body": "See the attached file: {}".format(uploaded_file["markdown"])
 })
-# project file upload markdown
+# end project file upload markdown
 
 # project file upload markdown custom
-uploaded_file = project.upload_file("filename.txt", filedata="data")
+uploaded_file = project.upload("filename.txt", filedata="data")
 issue = project.issues.get(issue_id)
 issue.notes.create({
     "body": "See the [attached file]({})".format(uploaded_file["url"])
 })
-# project file upload markdown
+# end project file upload markdown custom
+
+# users list
+users = p.users.list()
+
+# search for users
+users = p.users.list(search='pattern')
+# end users list
