@@ -34,7 +34,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab.v3.objects import *  # noqa
 
 __title__ = 'python-gitlab'
-__version__ = '1.0.2'
+__version__ = '1.1.0'
 __author__ = 'Gauvain Pocentek'
 __email__ = 'gauvain@pocentek.net'
 __license__ = 'LGPL3'
@@ -61,7 +61,9 @@ class Gitlab(object):
         private_token (str): The user private token
         email (str): The user email or login.
         password (str): The user password (associated with email).
-        ssl_verify (bool): Whether SSL certificates should be validated.
+        ssl_verify (bool|str): Whether SSL certificates should be validated. If
+            the value is a string, it is the path to a CA file used for
+            certificate validation.
         timeout (float): Timeout to use for requests to the GitLab server.
         http_username (str): Username for HTTP authentication
         http_password (str): Password for HTTP authentication
@@ -136,6 +138,17 @@ class Gitlab(object):
                     manager = getattr(objects, cls_name)(self)
                     setattr(self, var_name, manager)
 
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        state.pop('_objects')
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        objects = importlib.import_module('gitlab.v%s.objects' %
+                                          self._api_version)
+        self._objects = objects
+
     @property
     def api_version(self):
         return self._api_version
@@ -862,6 +875,7 @@ class GitlabList(object):
         except KeyError:
             self._next_url = None
         self._current_page = result.headers.get('X-Page')
+        self._prev_page = result.headers.get('X-Prev-Page')
         self._next_page = result.headers.get('X-Next-Page')
         self._per_page = result.headers.get('X-Per-Page')
         self._total_pages = result.headers.get('X-Total-Pages')
@@ -875,6 +889,42 @@ class GitlabList(object):
 
         self._current = 0
 
+    @property
+    def current_page(self):
+        """The current page number."""
+        return int(self._current_page)
+
+    @property
+    def prev_page(self):
+        """The next page number.
+
+        If None, the current page is the last.
+        """
+        return int(self._prev_page) if self._prev_page else None
+
+    @property
+    def next_page(self):
+        """The next page number.
+
+        If None, the current page is the last.
+        """
+        return int(self._next_page) if self._next_page else None
+
+    @property
+    def per_page(self):
+        """The number of items per page."""
+        return int(self._per_page)
+
+    @property
+    def total_pages(self):
+        """The total number of pages."""
+        return int(self._total_pages)
+
+    @property
+    def total(self):
+        """The total number of items."""
+        return int(self._total)
+
     def __iter__(self):
         return self
 
