@@ -18,6 +18,7 @@
 
 from __future__ import print_function
 
+import pickle
 try:
     import unittest
 except ImportError:
@@ -209,6 +210,12 @@ class TestGitlabList(unittest.TestCase):
             self.assertEqual(len(obj), 2)
             self.assertEqual(obj._next_url,
                              'http://localhost/api/v4/tests?per_page=1&page=2')
+            self.assertEqual(obj.current_page, 1)
+            self.assertEqual(obj.prev_page, None)
+            self.assertEqual(obj.next_page, 2)
+            self.assertEqual(obj.per_page, 1)
+            self.assertEqual(obj.total_pages, 2)
+            self.assertEqual(obj.total, 2)
 
             with HTTMock(resp_2):
                 l = list(obj)
@@ -884,6 +891,14 @@ class TestGitlab(unittest.TestCase):
                          email="testuser@test.com", password="testpassword",
                          ssl_verify=True)
 
+    def test_pickability(self):
+        original_gl_objects = self.gl._objects
+        pickled = pickle.dumps(self.gl)
+        unpickled = pickle.loads(pickled)
+        self.assertIsInstance(unpickled, Gitlab)
+        self.assertTrue(hasattr(unpickled, '_objects'))
+        self.assertEqual(unpickled._objects, original_gl_objects)
+
     def test_credentials_auth_nopassword(self):
         self.gl.email = None
         self.gl.password = None
