@@ -19,8 +19,6 @@ from __future__ import print_function
 from __future__ import absolute_import
 import base64
 
-import six
-
 from gitlab.base import *  # noqa
 from gitlab import cli
 from gitlab.exceptions import *  # noqa
@@ -125,6 +123,17 @@ class UserEmailManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
     _create_attrs = (('email', ), tuple())
 
 
+class UserGPGKey(ObjectDeleteMixin, RESTObject):
+    pass
+
+
+class UserGPGKeyManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
+    _path = '/users/%(user_id)s/gpg_keys'
+    _obj_cls = UserGPGKey
+    _from_parent_attrs = {'user_id': 'id'}
+    _create_attrs = (('key',), tuple())
+
+
 class UserKey(ObjectDeleteMixin, RESTObject):
     pass
 
@@ -137,7 +146,7 @@ class UserKeyManager(GetFromListMixin, CreateMixin, DeleteMixin, RESTManager):
 
 
 class UserProject(RESTObject):
-    _constructor_types = {'owner': 'User', 'namespace': 'Group'}
+    pass
 
 
 class UserProjectManager(CreateMixin, RESTManager):
@@ -157,6 +166,7 @@ class User(SaveMixin, ObjectDeleteMixin, RESTObject):
     _short_print_attr = 'username'
     _managers = (
         ('emails', 'UserEmailManager'),
+        ('gpgkeys', 'UserGPGKeyManager'),
         ('keys', 'UserKeyManager'),
         ('projects', 'UserProjectManager'),
     )
@@ -243,6 +253,17 @@ class CurrentUserEmailManager(RetrieveMixin, CreateMixin, DeleteMixin,
     _create_attrs = (('email', ), tuple())
 
 
+class CurrentUserGPGKey(ObjectDeleteMixin, RESTObject):
+    pass
+
+
+class CurrentUserGPGKeyManager(RetrieveMixin, CreateMixin, DeleteMixin,
+                               RESTManager):
+    _path = '/user/gpg_keys'
+    _obj_cls = CurrentUserGPGKey
+    _create_attrs = (('key',), tuple())
+
+
 class CurrentUserKey(ObjectDeleteMixin, RESTObject):
     _short_print_attr = 'title'
 
@@ -259,6 +280,7 @@ class CurrentUser(RESTObject):
     _short_print_attr = 'username'
     _managers = (
         ('emails', 'CurrentUserEmailManager'),
+        ('gpgkeys', 'CurrentUserGPGKeyManager'),
         ('keys', 'CurrentUserKeyManager'),
     )
 
@@ -362,6 +384,17 @@ class GitlabciymlManager(RetrieveMixin, RESTManager):
     _obj_cls = Gitlabciyml
 
 
+class GroupAccessRequest(AccessRequestMixin, ObjectDeleteMixin, RESTObject):
+    pass
+
+
+class GroupAccessRequestManager(GetFromListMixin, CreateMixin, DeleteMixin,
+                                RESTManager):
+    _path = '/groups/%(group_id)s/access_requests'
+    _obj_cls = GroupAccessRequest
+    _from_parent_attrs = {'group_id': 'id'}
+
+
 class GroupIssue(RESTObject):
     pass
 
@@ -386,6 +419,75 @@ class GroupMemberManager(GetFromListMixin, CreateMixin, UpdateMixin,
     _update_attrs = (('access_level', ), ('expires_at', ))
 
 
+class GroupMergeRequest(RESTObject):
+    pass
+
+
+class GroupMergeRequestManager(RESTManager):
+    pass
+
+
+class GroupMilestone(SaveMixin, ObjectDeleteMixin, RESTObject):
+    _short_print_attr = 'title'
+
+    @cli.register_custom_action('GroupMilestone')
+    @exc.on_http_error(exc.GitlabListError)
+    def issues(self, **kwargs):
+        """List issues related to this milestone.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabListError: If the list could not be retrieved
+
+        Returns:
+            RESTObjectList: The list of issues
+        """
+
+        path = '%s/%s/issues' % (self.manager.path, self.get_id())
+        data_list = self.manager.gitlab.http_list(path, as_list=False,
+                                                  **kwargs)
+        manager = GroupIssueManager(self.manager.gitlab,
+                                    parent=self.manager._parent)
+        # FIXME(gpocentek): the computed manager path is not correct
+        return RESTObjectList(manager, GroupIssue, data_list)
+
+    @cli.register_custom_action('GroupMilestone')
+    @exc.on_http_error(exc.GitlabListError)
+    def merge_requests(self, **kwargs):
+        """List the merge requests related to this milestone.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabListError: If the list could not be retrieved
+
+        Returns:
+            RESTObjectList: The list of merge requests
+        """
+        path = '%s/%s/merge_requests' % (self.manager.path, self.get_id())
+        data_list = self.manager.gitlab.http_list(path, as_list=False,
+                                                  **kwargs)
+        manager = GroupIssueManager(self.manager.gitlab,
+                                    parent=self.manager._parent)
+        # FIXME(gpocentek): the computed manager path is not correct
+        return RESTObjectList(manager, GroupMergeRequest, data_list)
+
+
+class GroupMilestoneManager(CRUDMixin, RESTManager):
+    _path = '/groups/%(group_id)s/milestones'
+    _obj_cls = GroupMilestone
+    _from_parent_attrs = {'group_id': 'id'}
+    _create_attrs = (('title', ), ('description', 'due_date', 'start_date'))
+    _update_attrs = (tuple(), ('title', 'description', 'due_date',
+                               'start_date', 'state_event'))
+    _list_filters = ('iids', 'state', 'search')
+
+
 class GroupNotificationSettings(NotificationSettings):
     pass
 
@@ -396,15 +498,72 @@ class GroupNotificationSettingsManager(NotificationSettingsManager):
     _from_parent_attrs = {'group_id': 'id'}
 
 
-class GroupAccessRequest(AccessRequestMixin, ObjectDeleteMixin, RESTObject):
+class GroupProject(RESTObject):
     pass
 
 
-class GroupAccessRequestManager(GetFromListMixin, CreateMixin, DeleteMixin,
-                                RESTManager):
-    _path = '/groups/%(group_id)s/access_requests'
-    _obj_cls = GroupAccessRequest
+class GroupProjectManager(GetFromListMixin, RESTManager):
+    _path = '/groups/%(group_id)s/projects'
+    _obj_cls = GroupProject
     _from_parent_attrs = {'group_id': 'id'}
+    _list_filters = ('archived', 'visibility', 'order_by', 'sort', 'search',
+                     'ci_enabled_first')
+
+
+class GroupVariable(SaveMixin, ObjectDeleteMixin, RESTObject):
+    _id_attr = 'key'
+
+
+class GroupVariableManager(CRUDMixin, RESTManager):
+    _path = '/groups/%(group_id)s/variables'
+    _obj_cls = GroupVariable
+    _from_parent_attrs = {'group_id': 'id'}
+    _create_attrs = (('key', 'value'), ('protected',))
+    _update_attrs = (('key', 'value'), ('protected',))
+
+
+class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
+    _short_print_attr = 'name'
+    _managers = (
+        ('accessrequests', 'GroupAccessRequestManager'),
+        ('members', 'GroupMemberManager'),
+        ('milestones', 'GroupMilestoneManager'),
+        ('notificationsettings', 'GroupNotificationSettingsManager'),
+        ('projects', 'GroupProjectManager'),
+        ('issues', 'GroupIssueManager'),
+        ('variables', 'GroupVariableManager'),
+    )
+
+    @cli.register_custom_action('Group', ('to_project_id', ))
+    @exc.on_http_error(exc.GitlabTransferProjectError)
+    def transfer_project(self, to_project_id, **kwargs):
+        """Transfer a project to this group.
+
+        Args:
+            to_project_id (int): ID of the project to transfer
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabTransferProjectError: If the project could not be transfered
+        """
+        path = '/groups/%d/projects/%d' % (self.id, to_project_id)
+        self.manager.gitlab.http_post(path, **kwargs)
+
+
+class GroupManager(CRUDMixin, RESTManager):
+    _path = '/groups'
+    _obj_cls = Group
+    _create_attrs = (
+        ('name', 'path'),
+        ('description', 'visibility', 'parent_id', 'lfs_enabled',
+         'request_access_enabled')
+    )
+    _update_attrs = (
+        tuple(),
+        ('name', 'path', 'description', 'visibility', 'lfs_enabled',
+         'request_access_enabled')
+    )
 
 
 class Hook(ObjectDeleteMixin, RESTObject):
@@ -420,9 +579,6 @@ class HookManager(NoUpdateMixin, RESTManager):
 
 class Issue(RESTObject):
     _url = '/issues'
-    _constructor_types = {'author': 'User',
-                          'assignee': 'User',
-                          'milestone': 'ProjectMilestone'}
     _short_print_attr = 'title'
 
 
@@ -444,7 +600,6 @@ class LicenseManager(RetrieveMixin, RESTManager):
 
 
 class Snippet(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User'}
     _short_print_attr = 'title'
 
     @cli.register_custom_action('Snippet')
@@ -510,7 +665,7 @@ class NamespaceManager(GetFromListMixin, RESTManager):
 
 
 class ProjectBoardList(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'label': 'ProjectLabel'}
+    pass
 
 
 class ProjectBoardListManager(CRUDMixin, RESTManager):
@@ -523,7 +678,6 @@ class ProjectBoardListManager(CRUDMixin, RESTManager):
 
 
 class ProjectBoard(RESTObject):
-    _constructor_types = {'labels': 'ProjectBoardList'}
     _managers = (('lists', 'ProjectBoardListManager'), )
 
 
@@ -534,7 +688,6 @@ class ProjectBoardManager(GetFromListMixin, RESTManager):
 
 
 class ProjectBranch(ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User', "committer": "User"}
     _id_attr = 'name'
 
     @cli.register_custom_action('ProjectBranch', tuple(),
@@ -587,10 +740,6 @@ class ProjectBranchManager(NoUpdateMixin, RESTManager):
 
 
 class ProjectJob(RESTObject):
-    _constructor_types = {'user': 'User',
-                          'commit': 'ProjectCommit',
-                          'runner': 'Runner'}
-
     @cli.register_custom_action('ProjectJob')
     @exc.on_http_error(exc.GitlabJobCancelError)
     def cancel(self, **kwargs):
@@ -909,7 +1058,7 @@ class ProjectHookManager(CRUDMixin, RESTManager):
 
 
 class ProjectIssueNote(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User'}
+    pass
 
 
 class ProjectIssueNoteManager(CRUDMixin, RESTManager):
@@ -922,8 +1071,6 @@ class ProjectIssueNoteManager(CRUDMixin, RESTManager):
 
 class ProjectIssue(SubscribableMixin, TodoMixin, TimeTrackingMixin, SaveMixin,
                    ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User', 'assignee': 'User', 'milestone':
-                          'ProjectMilestone'}
     _short_print_attr = 'title'
     _id_attr = 'iid'
     _managers = (('notes', 'ProjectIssueNoteManager'), )
@@ -980,7 +1127,7 @@ class ProjectMemberManager(CRUDMixin, RESTManager):
 
 
 class ProjectNote(RESTObject):
-    _constructor_types = {'author': 'User'}
+    pass
 
 
 class ProjectNoteManager(RetrieveMixin, RESTManager):
@@ -1001,8 +1148,6 @@ class ProjectNotificationSettingsManager(NotificationSettingsManager):
 
 
 class ProjectTag(ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'release': 'ProjectTagRelease',
-                          'commit': 'ProjectCommit'}
     _id_attr = 'name'
     _short_print_attr = 'name'
 
@@ -1022,7 +1167,8 @@ class ProjectTag(ObjectDeleteMixin, RESTObject):
             GitlabCreateError: If the server fails to create the release
             GitlabUpdateError: If the server fails to update the release
         """
-        path = '%s/%s/release' % (self.manager.path, self.get_id())
+        id = self.get_id().replace('/', '%2F')
+        path = '%s/%s/release' % (self.manager.path, id)
         data = {'description': description}
         if self.release is None:
             try:
@@ -1059,7 +1205,7 @@ class ProjectMergeRequestDiffManager(RetrieveMixin, RESTManager):
 
 
 class ProjectMergeRequestNote(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User'}
+    pass
 
 
 class ProjectMergeRequestNoteManager(CRUDMixin, RESTManager):
@@ -1072,7 +1218,6 @@ class ProjectMergeRequestNoteManager(CRUDMixin, RESTManager):
 
 class ProjectMergeRequest(SubscribableMixin, TodoMixin, TimeTrackingMixin,
                           SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'author': 'User', 'assignee': 'User'}
     _id_attr = 'iid'
 
     _managers = (
@@ -1242,8 +1387,8 @@ class ProjectMilestone(SaveMixin, ObjectDeleteMixin, RESTObject):
         path = '%s/%s/issues' % (self.manager.path, self.get_id())
         data_list = self.manager.gitlab.http_list(path, as_list=False,
                                                   **kwargs)
-        manager = ProjectCommitManager(self.manager.gitlab,
-                                       parent=self.manager._parent)
+        manager = ProjectIssueManager(self.manager.gitlab,
+                                      parent=self.manager._parent)
         # FIXME(gpocentek): the computed manager path is not correct
         return RESTObjectList(manager, ProjectIssue, data_list)
 
@@ -1265,8 +1410,8 @@ class ProjectMilestone(SaveMixin, ObjectDeleteMixin, RESTObject):
         path = '%s/%s/merge_requests' % (self.manager.path, self.get_id())
         data_list = self.manager.gitlab.http_list(path, as_list=False,
                                                   **kwargs)
-        manager = ProjectCommitManager(self.manager.gitlab,
-                                       parent=self.manager._parent)
+        manager = ProjectMergeRequestManager(self.manager.gitlab,
+                                             parent=self.manager._parent)
         # FIXME(gpocentek): the computed manager path is not correct
         return RESTObjectList(manager, ProjectMergeRequest, data_list)
 
@@ -1279,7 +1424,7 @@ class ProjectMilestoneManager(CRUDMixin, RESTManager):
                                    'state_event'))
     _update_attrs = (tuple(), ('title', 'description', 'due_date',
                                'start_date', 'state_event'))
-    _list_filters = ('iids', 'state')
+    _list_filters = ('iids', 'state', 'search')
 
 
 class ProjectLabel(SubscribableMixin, SaveMixin, ObjectDeleteMixin,
@@ -1431,11 +1576,35 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin,
         """
 
         self._check_missing_create_attrs(data)
-        file_path = data.pop('file_path')
+        file_path = data.pop('file_path').replace('/', '%2F')
         path = '%s/%s' % (self.path, file_path)
         server_data = self.gitlab.http_post(path, post_data=data, **kwargs)
         return self._obj_cls(self, server_data)
 
+    @exc.on_http_error(exc.GitlabUpdateError)
+    def update(self, file_path, new_data={}, **kwargs):
+        """Update an object on the server.
+
+        Args:
+            id: ID of the object to update (can be None if not required)
+            new_data: the update data for the object
+            **kwargs: Extra options to send to the Gitlab server (e.g. sudo)
+
+        Returns:
+            dict: The new object data (*not* a RESTObject)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabUpdateError: If the server cannot perform the request
+        """
+
+        data = new_data.copy()
+        file_path = file_path.replace('/', '%2F')
+        data['file_path'] = file_path
+        path = '%s/%s' % (self.path, file_path)
+        self._check_missing_update_attrs(data)
+        return self.gitlab.http_put(path, post_data=data, **kwargs)
+
     @cli.register_custom_action('ProjectFileManager', ('file_path', 'branch',
                                                        'commit_message'))
     @exc.on_http_error(exc.GitlabDeleteError)
@@ -1546,21 +1715,21 @@ class ProjectPipelineManager(RetrieveMixin, CreateMixin, RESTManager):
         return CreateMixin.create(self, data, path=path, **kwargs)
 
 
-class ProjectSnippetNote(RESTObject):
-    _constructor_types = {'author': 'User'}
+class ProjectSnippetNote(SaveMixin, ObjectDeleteMixin, RESTObject):
+    pass
 
 
-class ProjectSnippetNoteManager(RetrieveMixin, CreateMixin, RESTManager):
+class ProjectSnippetNoteManager(CRUDMixin, RESTManager):
     _path = '/projects/%(project_id)s/snippets/%(snippet_id)s/notes'
     _obj_cls = ProjectSnippetNote
     _from_parent_attrs = {'project_id': 'project_id',
                           'snippet_id': 'id'}
     _create_attrs = (('body', ), tuple())
+    _update_attrs = (('body', ), tuple())
 
 
 class ProjectSnippet(SaveMixin, ObjectDeleteMixin, RESTObject):
     _url = '/projects/%(project_id)s/snippets'
-    _constructor_types = {'author': 'User'}
     _short_print_attr = 'title'
     _managers = (('notes', 'ProjectSnippetNoteManager'), )
 
@@ -1617,6 +1786,17 @@ class ProjectTriggerManager(CRUDMixin, RESTManager):
     _update_attrs = (('description', ), tuple())
 
 
+class ProjectUser(RESTObject):
+    pass
+
+
+class ProjectUserManager(ListMixin, RESTManager):
+    _path = '/projects/%(project_id)s/users'
+    _obj_cls = ProjectUser
+    _from_parent_attrs = {'project_id': 'id'}
+    _list_filters = ('search',)
+
+
 class ProjectVariable(SaveMixin, ObjectDeleteMixin, RESTObject):
     _id_attr = 'key'
 
@@ -1767,8 +1947,21 @@ class ProjectRunnerManager(NoUpdateMixin, RESTManager):
     _create_attrs = (('runner_id', ), tuple())
 
 
+class ProjectWiki(SaveMixin, ObjectDeleteMixin, RESTObject):
+    _id_attr = 'slug'
+    _short_print_attr = 'slug'
+
+
+class ProjectWikiManager(CRUDMixin, RESTManager):
+    _path = '/projects/%(project_id)s/wikis'
+    _obj_cls = ProjectWiki
+    _from_parent_attrs = {'project_id': 'id'}
+    _create_attrs = (('title', 'content'), ('format', ))
+    _update_attrs = (tuple(), ('title', 'content', 'format'))
+    _list_filters = ('with_content', )
+
+
 class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _constructor_types = {'owner': 'User', 'namespace': 'Group'}
     _short_print_attr = 'path'
     _managers = (
         ('accessrequests', 'ProjectAccessRequestManager'),
@@ -1796,8 +1989,10 @@ class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
         ('services', 'ProjectServiceManager'),
         ('snippets', 'ProjectSnippetManager'),
         ('tags', 'ProjectTagManager'),
+        ('users', 'ProjectUserManager'),
         ('triggers', 'ProjectTriggerManager'),
         ('variables', 'ProjectVariableManager'),
+        ('wikis', 'ProjectWikiManager'),
     )
 
     @cli.register_custom_action('Project', tuple(), ('path', 'ref'))
@@ -1829,7 +2024,7 @@ class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
     @cli.register_custom_action('Project', ('sha', ))
     @exc.on_http_error(exc.GitlabGetError)
     def repository_blob(self, sha, **kwargs):
-        """Return a blob by blob SHA.
+        """Return a file by blob SHA.
 
         Args:
             sha(str): ID of the blob
@@ -1840,7 +2035,7 @@ class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabGetError: If the server failed to perform the request
 
         Returns:
-            str: The blob metadata
+            dict: The blob content and metadata
         """
 
         path = '/projects/%s/repository/blobs/%s' % (self.get_id(), sha)
@@ -2080,9 +2275,7 @@ class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabCreateError: If the server failed to perform the request
         """
         path = '/projects/%s/trigger/pipeline' % self.get_id()
-        form = {r'variables[%s]' % k: v for k, v in six.iteritems(variables)}
-        post_data = {'ref': ref, 'token': token}
-        post_data.update(form)
+        post_data = {'ref': ref, 'token': token, 'variables': variables}
         self.manager.gitlab.http_post(path, post_data=post_data, **kwargs)
 
     # see #56 - add file attachment features
@@ -2139,6 +2332,34 @@ class Project(SaveMixin, ObjectDeleteMixin, RESTObject):
         }
 
 
+class ProjectManager(CRUDMixin, RESTManager):
+    _path = '/projects'
+    _obj_cls = Project
+    _create_attrs = (
+        ('name', ),
+        ('path', 'namespace_id', 'description', 'issues_enabled',
+         'merge_requests_enabled', 'jobs_enabled', 'wiki_enabled',
+         'snippets_enabled', 'container_registry_enabled',
+         'shared_runners_enabled', 'visibility', 'import_url', 'public_jobs',
+         'only_allow_merge_if_build_succeeds',
+         'only_allow_merge_if_all_discussions_are_resolved', 'lfs_enabled',
+         'request_access_enabled', 'printing_merge_request_link_enabled')
+    )
+    _update_attrs = (
+        tuple(),
+        ('name', 'path', 'default_branch', 'description', 'issues_enabled',
+         'merge_requests_enabled', 'jobs_enabled', 'wiki_enabled',
+         'snippets_enabled', 'container_registry_enabled',
+         'shared_runners_enabled', 'visibility', 'import_url', 'public_jobs',
+         'only_allow_merge_if_build_succeeds',
+         'only_allow_merge_if_all_discussions_are_resolved', 'lfs_enabled',
+         'request_access_enabled', 'printing_merge_request_link_enabled')
+    )
+    _list_filters = ('search', 'owned', 'starred', 'archived', 'visibility',
+                     'order_by', 'sort', 'simple', 'membership', 'statistics',
+                     'with_issues_enabled', 'with_merge_requests_enabled')
+
+
 class Runner(SaveMixin, ObjectDeleteMixin, RESTObject):
     pass
 
@@ -2221,98 +2442,3 @@ class TodoManager(GetFromListMixin, DeleteMixin, RESTManager):
             return int(result)
         except ValueError:
             return 0
-
-
-class ProjectManager(CRUDMixin, RESTManager):
-    _path = '/projects'
-    _obj_cls = Project
-    _create_attrs = (
-        ('name', ),
-        ('path', 'namespace_id', 'description', 'issues_enabled',
-         'merge_requests_enabled', 'jobs_enabled', 'wiki_enabled',
-         'snippets_enabled', 'container_registry_enabled',
-         'shared_runners_enabled', 'visibility', 'import_url', 'public_jobs',
-         'only_allow_merge_if_build_succeeds',
-         'only_allow_merge_if_all_discussions_are_resolved', 'lfs_enabled',
-         'request_access_enabled')
-    )
-    _update_attrs = (
-        tuple(),
-        ('name', 'path', 'default_branch', 'description', 'issues_enabled',
-         'merge_requests_enabled', 'jobs_enabled', 'wiki_enabled',
-         'snippets_enabled', 'container_registry_enabled',
-         'shared_runners_enabled', 'visibility', 'import_url', 'public_jobs',
-         'only_allow_merge_if_build_succeeds',
-         'only_allow_merge_if_all_discussions_are_resolved', 'lfs_enabled',
-         'request_access_enabled')
-    )
-    _list_filters = ('search', 'owned', 'starred', 'archived', 'visibility',
-                     'order_by', 'sort', 'simple', 'membership', 'statistics',
-                     'with_issues_enabled', 'with_merge_requests_enabled')
-
-
-class GroupProject(Project):
-    pass
-
-
-class GroupProjectManager(GetFromListMixin, RESTManager):
-    _path = '/groups/%(group_id)s/projects'
-    _obj_cls = GroupProject
-    _from_parent_attrs = {'group_id': 'id'}
-    _list_filters = ('archived', 'visibility', 'order_by', 'sort', 'search',
-                     'ci_enabled_first')
-
-
-class GroupVariable(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _id_attr = 'key'
-
-
-class GroupVariableManager(CRUDMixin, RESTManager):
-    _path = '/groups/%(group_id)s/variables'
-    _obj_cls = GroupVariable
-    _from_parent_attrs = {'group_id': 'id'}
-    _create_attrs = (('key', 'value'), ('protected',))
-    _update_attrs = (('key', 'value'), ('protected',))
-
-
-class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
-    _short_print_attr = 'name'
-    _managers = (
-        ('accessrequests', 'GroupAccessRequestManager'),
-        ('members', 'GroupMemberManager'),
-        ('notificationsettings', 'GroupNotificationSettingsManager'),
-        ('projects', 'GroupProjectManager'),
-        ('issues', 'GroupIssueManager'),
-        ('variables', 'GroupVariableManager'),
-    )
-
-    @cli.register_custom_action('Group', ('to_project_id', ))
-    @exc.on_http_error(exc.GitlabTransferProjectError)
-    def transfer_project(self, to_project_id, **kwargs):
-        """Transfer a project to this group.
-
-        Args:
-            to_project_id (int): ID of the project to transfer
-            **kwargs: Extra options to send to the server (e.g. sudo)
-
-        Raises:
-            GitlabAuthenticationError: If authentication is not correct
-            GitlabTransferProjectError: If the project could not be transfered
-        """
-        path = '/groups/%d/projects/%d' % (self.id, to_project_id)
-        self.manager.gitlab.http_post(path, **kwargs)
-
-
-class GroupManager(CRUDMixin, RESTManager):
-    _path = '/groups'
-    _obj_cls = Group
-    _create_attrs = (
-        ('name', 'path'),
-        ('description', 'visibility', 'parent_id', 'lfs_enabled',
-         'request_access_enabled')
-    )
-    _update_attrs = (
-        tuple(),
-        ('name', 'path', 'description', 'visibility', 'lfs_enabled',
-         'request_access_enabled')
-    )
