@@ -25,10 +25,12 @@ error() { log "ERROR: $@" >&2; }
 fatal() { error "$@"; exit 1; }
 try() { "$@" || fatal "'$@' failed"; }
 
+NOVENV=
 PY_VER=2
-API_VER=3
-while getopts :p:a: opt "$@"; do
+API_VER=4
+while getopts :np:a: opt "$@"; do
     case $opt in
+        n) NOVENV=1;;
         p) PY_VER=$OPTARG;;
         a) API_VER=$OPTARG;;
         :) fatal "Option -${OPTARG} requires a value";;
@@ -62,18 +64,12 @@ CONFIG=/tmp/python-gitlab.cfg
 
 cleanup() {
     rm -f "${CONFIG}"
-    log "Stopping gitlab-test docker container..."
-    docker stop gitlab-test >/dev/null &
-    docker_stop_pid=$!
-    log "Waiting for gitlab-test docker container to exit..."
-    docker wait gitlab-test >/dev/null
-    wait "${docker_stop_pid}"
-    log "Removing gitlab-test docker container..."
-    docker rm gitlab-test >/dev/null
     log "Deactivating Python virtualenv..."
     command -v deactivate >/dev/null 2>&1 && deactivate || true
     log "Deleting python virtualenv..."
     rm -rf "$VENV"
+    log "Stopping gitlab-test docker container..."
+    docker rm -f gitlab-test >/dev/null
     log "Done."
 }
 [ -z "${BUILD_TEST_ENV_AUTO_CLEANUP+set}" ] || {
@@ -143,17 +139,19 @@ EOF
 log "Config file content ($CONFIG):"
 log <$CONFIG
 
-log "Creating Python virtualenv..."
-try "$VENV_CMD" "$VENV"
-. "$VENV"/bin/activate || fatal "failed to activate Python virtual environment"
+if [ -z "$NOVENV" ]; then
+    log "Creating Python virtualenv..."
+    try "$VENV_CMD" "$VENV"
+    . "$VENV"/bin/activate || fatal "failed to activate Python virtual environment"
 
-log "Installing dependencies into virtualenv..."
-try pip install -rrequirements.txt
+    log "Installing dependencies into virtualenv..."
+    try pip install -rrequirements.txt
 
-log "Installing into virtualenv..."
-try pip install -e .
+    log "Installing into virtualenv..."
+    try pip install -e .
+fi
 
 log "Pausing to give GitLab some time to finish starting up..."
-sleep 20
+sleep 30
 
 log "Test environment initialized."
